/*
* Copyright (c) 2012 The Broad Institute
* 
* Permission is hereby granted, free of charge, to any person
* obtaining a copy of this software and associated documentation
* files (the "Software"), to deal in the Software without
* restriction, including without limitation the rights to use,
* copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the
* Software is furnished to do so, subject to the following
* conditions:
* 
* The above copyright notice and this permission notice shall be
* included in all copies or substantial portions of the Software.
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
* EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
* OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
* NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
* HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
* FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
* THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

package org.broadinstitute.sting.gatk.samples;

/**
 * Categorical sample trait for association and analysis
 *
 * Samples can have unknown status, be affected or unaffected by the
 * categorical trait, or they can be marked as actually having an
 * other trait value (stored in an associated value in the Sample class)
 *
 * @author Mark DePristo
 * @since Sept. 2011
 */
public enum Affection {
    /** Status is unknown */
    UNKNOWN,
    /** Suffers from the disease */
    AFFECTED,
    /** Unaffected by the disease */
    UNAFFECTED,
    /** An "other" trait: value of the trait is stored elsewhere and is an arbitrary string */
    OTHER
}
